@@ -5,9 +5,10 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
+import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_kms._jsii
 import aws_cdk.aws_logs._jsii
@@ -15,7 +16,7 @@ import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-kinesis", "1.56.0", __name__[0:-6], "aws-kinesis@1.56.0.jsii.tgz"
+    "@aws-cdk/aws-kinesis", "1.124.0", __name__[0:-6], "aws-kinesis@1.124.0.jsii.tgz"
 )
 
 __all__ = [
